/*
 * Copyright (c) 2022-2023 AccelByte Inc. All Rights Reserved
 * This is licensed software from AccelByte Inc, for limitations
 * and restrictions contact your company contract manager.
 */
/**
 * AUTO GENERATED
 */
import { CodeGenUtil, SdkCache, Validate } from '@accelbyte/sdk';
import { z } from 'zod';
import { UserProfileInfo } from '../definitions/UserProfileInfo.js';
import { UserProfilePrivateInfo } from '../definitions/UserProfilePrivateInfo.js';
import { UserProfilePublicInfo } from '../definitions/UserProfilePublicInfo.js';
import { UserProfilePublicInfoArray } from '../definitions/UserProfilePublicInfoArray.js';
import { UserZipCode } from '../definitions/UserZipCode.js';
export class UserProfile$ {
    // @ts-ignore
    constructor(axiosInstance, namespace, cache = false) {
        this.axiosInstance = axiosInstance;
        this.namespace = namespace;
        this.cache = cache;
    }
    /**
     * Get user public profile by ids.<br>Other detail info: <ul><li><i>Action code</i>: 11405</li><li><i>Returns</i>: user public profiles</li></ul>
     */
    getProfilesPublic(queryParams) {
        const params = { ...queryParams };
        const url = '/basic/v1/public/namespaces/{namespace}/profiles/public'.replace('{namespace}', this.namespace);
        const resultPromise = this.axiosInstance.get(url, { params });
        const res = () => Validate.responseType(() => resultPromise, UserProfilePublicInfoArray, 'UserProfilePublicInfoArray');
        if (!this.cache) {
            return SdkCache.withoutCache(res);
        }
        const cacheKey = url + CodeGenUtil.hashCode(JSON.stringify({ params }));
        return SdkCache.withCache(cacheKey, res);
    }
    /**
     * Get my profile<br><b>Client with user token can get user profile in target namespace</b><br>Other detail info: <ul><li><i>Required permission</i>: resource=<b>"NAMESPACE:{namespace}:PROFILE"</b>, action=2 <b>(READ)</b></li><li><i>Action code</i>: 11403</li><li><i>Returns</i>: user profile</li><li><i>Path's namespace</i> : <ul><li>can be filled with <b>publisher namespace</b> in order to get <b>publisher user profile</b></li><li>can be filled with <b>game namespace</b> in order to get <b>game user profile</b></li></ul></li><li><i>Language</i> : allowed format: en, en-US</li><li><i>Timezone</i> : IANA time zone, e.g. Asia/Shanghai</li></ul>
     */
    getUsersMeProfiles() {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/me/profiles'.replace('{namespace}', this.namespace);
        const resultPromise = this.axiosInstance.get(url, { params });
        const res = () => Validate.responseType(() => resultPromise, UserProfilePrivateInfo, 'UserProfilePrivateInfo');
        if (!this.cache) {
            return SdkCache.withoutCache(res);
        }
        const cacheKey = url + CodeGenUtil.hashCode(JSON.stringify({ params }));
        return SdkCache.withCache(cacheKey, res);
    }
    /**
     * Create my profile.<br><b>Client with user token can create user profile in target namespace</b><br>Other detail info: <ul><li><i>Required permission</i>: resource=<b>"NAMESPACE:{namespace}:PROFILE"</b>, action=1 <b>(CREATE)</b></li><li><i>Action code</i>: 11401</li><li><i>Returns</i>: Created user profile</li><li><i>Path's namespace</i> : <ul><li>can be filled with <b>publisher namespace</b> in order to create <b>publisher user profile</b></li><li>can be filled with <b>game namespace</b> in order to create <b>game user profile</b></li></ul></li><li><i>Language</i> : allowed format: en, en-US</li><li><i>Country</i> : ISO3166-1 alpha-2 two letter, e.g. US </li><li><i>Timezone</i> : IANA time zone, e.g. Asia/Shanghai</li></ul>
     */
    createUserMeProfile(data) {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/me/profiles'.replace('{namespace}', this.namespace);
        const resultPromise = this.axiosInstance.post(url, data, { params });
        return Validate.responseType(() => resultPromise, UserProfilePrivateInfo, 'UserProfilePrivateInfo');
    }
    /**
     * Update my profile.<br>Updates user profile in the target namespace (namespace in the path). If token's namespace doesn't match the target namespace, the service automatically maps the token's user ID into the user ID in the target namespace. The endpoint returns the updated user profile on a successful call.<br>Other detail info: <ul><li><i>Required permission</i>: resource=<b>"NAMESPACE:{namespace}:PROFILE"</b>, action=4 <b>(UPDATE)</b></li><li><i>Action code</i>: 11402</li><li><i>Returns</i>: user profile</li><li><i>Path's namespace</i> : <ul><li>can be filled with <b>publisher namespace</b> in order to update <b>publisher user profile</b></li><li>can be filled with <b>game namespace</b> in order to update <b>game user profile</b></li></ul></li><li><i>Language</i> : allowed format: en, en-US</li><li><i>Timezone</i> : IANA time zone, e.g. Asia/Shanghai</li></ul>
     */
    updateUserMeProfile(data) {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/me/profiles'.replace('{namespace}', this.namespace);
        const resultPromise = this.axiosInstance.put(url, data, { params });
        return Validate.responseType(() => resultPromise, UserProfilePrivateInfo, 'UserProfilePrivateInfo');
    }
    /**
     * Get user profile.<br>Other detail info: <ul><li><i>Required permission</i>: resource=<b>"NAMESPACE:{namespace}:USER:{userId}:PROFILE"</b>, action=2 <b>(READ)</b></li><li><i>Action code</i>: 11403</li><li><i>Returns</i>: user profile</li></ul>
     */
    getProfiles_ByUserId(userId) {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/{userId}/profiles'
            .replace('{namespace}', this.namespace)
            .replace('{userId}', userId);
        const resultPromise = this.axiosInstance.get(url, { params });
        const res = () => Validate.responseType(() => resultPromise, UserProfileInfo, 'UserProfileInfo');
        if (!this.cache) {
            return SdkCache.withoutCache(res);
        }
        const cacheKey = url + CodeGenUtil.hashCode(JSON.stringify({ params }));
        return SdkCache.withCache(cacheKey, res);
    }
    /**
     * Create user profile.<br>Other detail info: <ul><li><i>Required permission</i>: resource=<b>"NAMESPACE:{namespace}:USER:{userId}:PROFILE"</b>, action=1 <b>(CREATE)</b></li><li><i>Action code</i>: 11401</li><li><i>Language</i> : allowed format: en, en-US</li><li><i>Timezone</i> : IANA time zone, e.g. Asia/Shanghai</li><li><i>Returns</i>: Created user profile</li></ul>
     */
    createProfile_ByUserId(userId, data) {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/{userId}/profiles'
            .replace('{namespace}', this.namespace)
            .replace('{userId}', userId);
        const resultPromise = this.axiosInstance.post(url, data, { params });
        return Validate.responseType(() => resultPromise, UserProfileInfo, 'UserProfileInfo');
    }
    /**
     * Update user profile.<br>Other detail info: <ul><li><i>Required permission</i>: resource=<b>"NAMESPACE:{namespace}:USER:{userId}:PROFILE"</b>, action=4 <b>(UPDATE)</b></li><li><i>Action code</i>: 11402</li><li><i>Language</i> : allowed format: en, en-US</li><li><i>Timezone</i> : IANA time zone, e.g. Asia/Shanghai</li><li><i>Returns</i>: Updated user profile</li></ul>
     */
    updateProfile_ByUserId(userId, data) {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/{userId}/profiles'
            .replace('{namespace}', this.namespace)
            .replace('{userId}', userId);
        const resultPromise = this.axiosInstance.put(url, data, { params });
        return Validate.responseType(() => resultPromise, UserProfileInfo, 'UserProfileInfo');
    }
    /**
     * Get my zip code.<br>Other detail info: <ul><li><i>Required permission</i>: resource=<b>"NAMESPACE:{namespace}:PROFILE"</b>, action=2 <b>(READ)</b></li><li><i>Action code</i>: 11407</li><li><i>Returns</i>: user zip code</li></ul>
     */
    getUsersMeProfilesZipCode() {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/me/profiles/zipCode'.replace('{namespace}', this.namespace);
        const resultPromise = this.axiosInstance.get(url, { params });
        const res = () => Validate.responseType(() => resultPromise, UserZipCode, 'UserZipCode');
        if (!this.cache) {
            return SdkCache.withoutCache(res);
        }
        const cacheKey = url + CodeGenUtil.hashCode(JSON.stringify({ params }));
        return SdkCache.withCache(cacheKey, res);
    }
    /**
     * Update my zip code.<br>Other detail info: <ul><li><i>Required permission</i>: resource=<b>"NAMESPACE:{namespace}:PROFILE"</b>, action=4 <b>(UPDATE)</b></li><li><i>Action code</i>: 11408</li><li><i>Returns</i>: user zip code</li></ul>
     */
    patchUserMeProfileZipCode(data) {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/me/profiles/zipCode'.replace('{namespace}', this.namespace);
        const resultPromise = this.axiosInstance.patch(url, data, { params });
        return Validate.responseType(() => resultPromise, UserZipCode, 'UserZipCode');
    }
    /**
     * Get user public profile by public id.<br>Other detail info: <ul><li><i>Returns</i>: user public profile</li></ul>
     */
    getProfilesPublicByPublicId(queryParams) {
        const params = { ...queryParams };
        const url = '/basic/v1/public/namespaces/{namespace}/profiles/public/byPublicId'.replace('{namespace}', this.namespace);
        const resultPromise = this.axiosInstance.get(url, { params });
        const res = () => Validate.responseType(() => resultPromise, UserProfilePublicInfo, 'UserProfilePublicInfo');
        if (!this.cache) {
            return SdkCache.withoutCache(res);
        }
        const cacheKey = url + CodeGenUtil.hashCode(JSON.stringify({ params }));
        return SdkCache.withCache(cacheKey, res);
    }
    /**
     * Get user profile public info.<br>Other detail info: <ul><li><i>Action code</i>: 11404</li><li><i>Returns</i>: user public profile</li></ul>
     */
    getProfilesPublic_ByUserId(userId) {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/{userId}/profiles/public'
            .replace('{namespace}', this.namespace)
            .replace('{userId}', userId);
        const resultPromise = this.axiosInstance.get(url, { params });
        const res = () => Validate.responseType(() => resultPromise, UserProfilePublicInfo, 'UserProfilePublicInfo');
        if (!this.cache) {
            return SdkCache.withoutCache(res);
        }
        const cacheKey = url + CodeGenUtil.hashCode(JSON.stringify({ params }));
        return SdkCache.withCache(cacheKey, res);
    }
    /**
     * Update user profile status.<br>Other detail info: <ul><li><i>Required permission</i>: resource=<b>"NAMESPACE:{namespace}:USER:{userId}:PROFILE"</b>, action=4 <b>(UPDATE)</b></li><li><i>Action code</i>: 11406</li><li><i>Returns</i>: user profile</li></ul>
     */
    patchProfileStatus_ByUserId(userId, data) {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/{userId}/profiles/status'
            .replace('{namespace}', this.namespace)
            .replace('{userId}', userId);
        const resultPromise = this.axiosInstance.patch(url, data, { params });
        return Validate.responseType(() => resultPromise, UserProfileInfo, 'UserProfileInfo');
    }
    /**
     * Get custom attributes info.<br>Other detail info: <ul><li><i>Action code</i>: 11404</li><li><i>Returns</i>: user custom attributes</li></ul>
     */
    getProfilesCustomAttributes_ByUserId(userId) {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/{userId}/profiles/customAttributes'
            .replace('{namespace}', this.namespace)
            .replace('{userId}', userId);
        const resultPromise = this.axiosInstance.get(url, { params });
        const res = () => Validate.responseType(() => resultPromise, z.unknown(), 'z.unknown()');
        if (!this.cache) {
            return SdkCache.withoutCache(res);
        }
        const cacheKey = url + CodeGenUtil.hashCode(JSON.stringify({ params }));
        return SdkCache.withCache(cacheKey, res);
    }
    /**
     * Update partially custom attributes tied to user id.<br>Other detail info: <ul><li><i>Required permission</i>: resource=<b>"NAMESPACE:{namespace}:USER:{userId}:PROFILE"</b>, action=4 <b>(UPDATE)</b></li><li><i>Action code</i>: 11402</li><li><i>Request body</i> : allowed format: JSON object</li><li><i>Returns</i>: Updated custom attributes</li></ul>
     */
    updateProfileCustomAttribute_ByUserId(userId, data) {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/{userId}/profiles/customAttributes'
            .replace('{namespace}', this.namespace)
            .replace('{userId}', userId);
        const resultPromise = this.axiosInstance.put(url, data, { params });
        return Validate.responseType(() => resultPromise, z.unknown(), 'z.unknown()');
    }
    /**
     * Get my private custom attributes.<br>Other detail info: <ul><li><i>Required permission</i>: resource=<b>"NAMESPACE:{namespace}:PROFILE"</b>, action=2 <b>(READ)</b></li><li><i>Returns</i>: custom attributes</li><li><i>Action code</i>: 11403</li></ul>
     */
    getUsersMeProfilesPrivateCustomAttributes() {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/me/profiles/privateCustomAttributes'.replace('{namespace}', this.namespace);
        const resultPromise = this.axiosInstance.get(url, { params });
        const res = () => Validate.responseType(() => resultPromise, z.unknown(), 'z.unknown()');
        if (!this.cache) {
            return SdkCache.withoutCache(res);
        }
        const cacheKey = url + CodeGenUtil.hashCode(JSON.stringify({ params }));
        return SdkCache.withCache(cacheKey, res);
    }
    /**
     * Update partially private custom attributes tied to me.<br>Other detail info: <ul><li><i>Required permission</i>: resource=<b>"NAMESPACE:{namespace}:PROFILE"</b>, action=4 <b>(UPDATE)</b></li><li><i>Action code</i>: 11402</li><li><i>Request body</i>: allowed format: JSON object</li><li><i>Returns</i>: Updated custom attributes</li></ul>
     */
    updateUserMeProfilePrivateCustomAttribute(data) {
        const params = {};
        const url = '/basic/v1/public/namespaces/{namespace}/users/me/profiles/privateCustomAttributes'.replace('{namespace}', this.namespace);
        const resultPromise = this.axiosInstance.put(url, data, { params });
        return Validate.responseType(() => resultPromise, z.unknown(), 'z.unknown()');
    }
}
